
#############################################\n
Я сделал этот модуль для того чтобы мне в разных местах
было проще делать что-то новое, уникальное.
В основном я собираюсь делать этот модуль в свое свободное время
#############################################\n
I made this module
so that it would be easier for me to do something new and unique in different places.
I'm mainly going to do this module in my free time.
#############################################\n